Struct ZxdgExportedV2
pub struct ZxdgExportedV2 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
an exported surface handle
An xdg_exported object represents an exported reference to a surface. The exported surface may be referenced as long as the xdg_exported object not destroyed. Destroying the xdg_exported invalidates any relationship the importer may have established using xdg_imported.
See also the Event enum for this interface.
Implementations
impl ZxdgExportedV2
impl ZxdgExportedV2
pub fn destroy(&self)
pub fn destroy(&self)
unexport the exported surface
Revoke the previously exported surface. This invalidates any relationship the importer may have set up using the xdg_imported created given the handle sent via xdg_exported.handle.